@@ -21,11 +21,8 @@
 
 #include <sys/param.h>
 
-#if __FreeBSD_version >= 1100000
-#error This driver does not support FreeBSD 11.x/-CURRENT!
-#endif
-#if __FreeBSD_version >= 1000000 && __FreeBSD_version < 1000510
-#error This driver requires FreeBSD 10.0 or later!
+#if __FreeBSD_version >= 1000000
+#error This driver does not support FreeBSD 10.x/-CURRENT!
 #endif
 #if __FreeBSD_version >= 900000 && __FreeBSD_version < 900044
 #error This driver requires FreeBSD 9.0 or later!
@@ -65,7 +62,6 @@
 #include <sys/mman.h>
 #include <sys/file.h>
 #include <sys/poll.h>
-#include <sys/rwlock.h>
 
 #include <sys/syscall.h>
 #include <sys/bus.h>
@@ -84,13 +80,6 @@
 #include <vm/vm_pager.h>
 #include <vm/uma.h>
 
-#if __FreeBSD_version < 800004
-#include <pci/agpvar.h>
-#else
-#include <dev/agp/agpvar.h>
-#endif
-#include <sys/agpio.h>
-
 #include <sys/smp.h>
 #include <dev/pci/pcireg.h>
 #include <dev/pci/pcivar.h>
@@ -113,11 +102,8 @@
 
 #if __FreeBSD_version >= 900041
 #include <sys/capability.h>
-#if __FreeBSD_version < 1000053
-#define cap_rights_init(rights, cap) (cap)
-#endif
 #else
-#define fget(td, fd, rights, fp) fget(td, fd, fp)
+#define fget(td, fd, cap, fp) fget(td, fd, fp)
 #endif
 
 #define __NV_ITHREAD() (curthread->td_pflags & TDP_ITHREAD)
@@ -130,14 +116,6 @@
 
 MALLOC_DECLARE(M_NVIDIA);
 
-/*
- * Enable/Disable support for FreeBSD's AGP GART driver. Please note that
- * agp.ko may need to be preloaded from loader.conf; this define does not
- * influence support for NVIDIA's builtin AGP GART driver.
- */
-
-#undef NV_SUPPORT_OS_AGP
-
 /*
  * This option decides if the driver will be built with support for Linux
  * or Linux 32-bit (FreeBSD/amd64) compatibility. This makes nvidia.ko
@@ -161,13 +139,6 @@ MALLOC_DECLARE(M_NVIDIA);
 
 #undef NV_USE_WBINVD
 
-/*
- * The DMA memory allocation tracking structure. DMA memory alloctions on
- * FreeBSD are tracked with their base address and size. Since PCI memory
- * is allocated from kernel virtual memory and since AGP allocations have
- * a contiguous range of addresses in the AGP aperture, base and size are
- * sufficient to track allocations.
- */
 typedef
 struct nvidia_pte {
     vm_offset_t virtual_address;
@@ -208,10 +179,6 @@ struct nvidia_work {
 typedef
 struct nvidia_softc {
     device_t dev;
-    device_t agp_dev;
-
-    struct sglist *AGP_sg_list;
-    vm_object_t AGP_object;
 
     struct sglist *UD_sg_list;
     vm_object_t UD_object;
@@ -341,7 +308,8 @@ NvU8   nvidia_pci_find_capability     (device_t dev, NvU8);
 #define NV_PCI_CHECK_CONFIG_SPACE(sp,nv,cb,as,mb)                       \
     {                                                                   \
         struct nvidia_softc *__sc;                                      \
-        if (((nv)->flags & NV_FLAG_CONTROL) == 0) {                     \
+        if ((((nv)->flags & NV_FLAG_CONTROL) == 0) &&                   \
+            (((nv)->flags & NV_FLAG_SKIP_CFG_CHECK) == 0)) {            \
             __sc = (nv)->os_state;                                      \
             nvidia_pci_check_config_space(sp, __sc->dev, cb, as, mb);   \
         }                                                               \
@@ -367,11 +335,6 @@ NvS32  nv_free_contig_pages  (nv_state_t *, void *);
 NvS32  nv_alloc_system_pages (nv_state_t *, NvU32, NvU32, NvBool, NvU64 *, void **);
 NvS32  nv_free_system_pages  (nv_state_t *, void *);
 
-NvS32  nv_os_agp_init        (nv_stack_t *sp, nv_state_t *, NvU64 *, NvU64 *);
-NvS32  nv_os_agp_teardown    (nv_stack_t *sp, nv_state_t *);
-NvS32  nv_alloc_agp_pages    (nv_state_t *, NvU32, NvU32, void **);
-NvS32  nv_free_agp_pages     (nv_state_t *, NvU32, void *, NvU32 *);
-
 #define NV_SGLIST_FREE(sgl)             \
     {                                   \
         sglist_free(sgl);               \
@@ -384,27 +347,12 @@ NvS32  nv_free_agp_pages     (nv_state_t *, NvU32, void *, NvU32 *);
         (obj) = NULL;                   \
     }
 
-#if __FreeBSD_version < 1000030
-#define VM_OBJECT_WLOCK(object) VM_OBJECT_LOCK(object)
-#define VM_OBJECT_WUNLOCK(object) VM_OBJECT_UNLOCK(object)
-#endif
-
-#if __FreeBSD_version < 1000055
-#define vm_map_find(map, object, offset, addr, length, \
-        max_addr, find_space, prot, max, cow) \
-  vm_map_find(map, object, offset, addr, length, find_space, prot, max, cow)
-#endif
-
-#if __FreeBSD_version < 1000042
-#define kmem_arena kernel_map
-#endif
-
 #if __FreeBSD_version >= 800000
-#define NV_VM_PAGER_ALLOCATE(type, handle, size, prot, off, cred) \
-  vm_pager_allocate(type, handle, size, prot, off, cred)
+#define NV_VM_PAGER_ALLOCATE(tp,hd,sz,pt,of,cr) \
+  vm_pager_allocate(tp, hd, sz, pt, of, cr)
 #else
-#define NV_VM_PAGER_ALLOCATE(type, handle, size, prot, off, cred) \
-  vm_pager_allocate(type, handle, size, prot, off)
+#define NV_VM_PAGER_ALLOCATE(tp,hd,sz,pt,of,cr) \
+  vm_pager_allocate(tp, hd, sz, pt, of)
 #endif
 
 #if __FreeBSD_version >= 800000
@@ -425,17 +373,6 @@ int    nvidia_sysctl_bus_type   (SYSCTL_HANDLER_ARGS);
 int    nvidia_sysctl_registry_key     (SYSCTL_HANDLER_ARGS);
 int    nvidia_sysctl_registry_dwords  (SYSCTL_HANDLER_ARGS);
 
-int    nvidia_sysctl_agp_rates      (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_fw         (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_sba        (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_registers  (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_driver     (SYSCTL_HANDLER_ARGS);
-
-int    nvidia_sysctl_agp_status       (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_rate_status  (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_fw_status    (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_sba_status   (SYSCTL_HANDLER_ARGS);
-
 void   nv_sysctl_init        (nv_state_t *);
 void   nv_sysctl_exit        (nv_state_t *);
 
