@@ -9,60 +9,12 @@
  * _NVRM_COPYRIGHT_END_
  */
 
-/*
- * Registry variables.
- *
- * These are defined here and used throughout resman. 
- * Any given registry name (windows registry leaf names) are mapped to
- * variables with the following naming convention: NVreg_NAME, where NAME
- * is the registry name with space converted to underscores.
- *
- */
-
-/*
- * Steps to be followed for the addition of a new registry key
- * 
- * Step 1: document and define registry key
- *
- * example:
- * Option: EnableVia4x
- *
- * Description:
- *
- * We've had problems with some Via chipsets in 4x mode, we need force
- * them back down to 2x mode. If you'd like to experiment with retaining
- * 4x mode, you may try setting this value to 1 If that hangs the system,
- * you're stuck with 2x mode; there's nothing we can do about it.
- *
- * Possible Values:
- *
- * 0: disable AGP 4x on Via chipsets (default)
- * 1: enable  AGP 4x on Via chipsets
- *
- * #define __NV_ENABLE_VIA_4X EnableVia4x
- * #define NV_REG_ENABLE_VIA_4X NV_REG_STRING(__NV_ENABLE_VIA_4X)
- *
- * Step 2: registry key parameter declarations
- *
- * example:
- * NV_DEFINE_REG_ENTRY(__NV_ENABLE_VIA_4X, 0);
- *
- * Step 3: registry database definition
- *
- * example:
- * nv_parm_t nv_parms[] = {
- *     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_VIA_4X),
- * };
- *
- */
-
 #ifndef _RM_REG_H_
 #define _RM_REG_H_
 
 #include "nvtypes.h"
 
-
-/* 
+/*
  * use NV_REG_STRING to stringify a registry key when using that registry key 
  */
 
@@ -103,154 +55,6 @@
  */
 
 /*
- * Option: EnableVia4x
- *
- * Description:
- *
- * We've had problems with some Via chipsets in 4x mode, we need force
- * them back down to 2x mode. If you'd like to experiment with retaining
- * 4x mode, you may try setting this value to 1 If that hangs the system,
- * you're stuck with 2x mode; there's nothing we can do about it.
- *
- * Possible Values:
- *
- * 0: disable AGP 4x on Via chipsets (default)
- * 1: enable  AGP 4x on Via chipsets
- */
-
-#define __NV_ENABLE_VIA_4X EnableVia4x
-#define NV_REG_ENABLE_VIA_4X NV_REG_STRING(__NV_ENABLE_VIA_4X)
-
-/*
- * Option: EnableALiAGP
- *
- * Description:
- *
- * Some ALi chipsets (ALi1541, ALi1647) are known to cause severe system
- * stability problems with AGP enabled. To avoid lockups, we disable AGP
- * on systems with these chipsets by default. It appears that updating the
- * system BIOS and using recent versions of the kernel AGP Gart driver can
- * make such systems much more stable. If you own a system with one of the
- * aforementioned chipsets and had it working reasonably well previously,
- * or if you want to experiment with BIOS and AGPGART revisions, you can
- * re-enable AGP support by setting this option to 1.
- *
- * Possible Values:
- *
- *  0: disable AGP on Ali1541 and ALi1647 (default)
- *  1: enable  AGP on Ali1541 and ALi1647
- */
-
-#define __NV_ENABLE_ALI_AGP EnableALiAGP
-#define NV_REG_ENABLE_ALI_AGP NV_REG_STRING(__NV_ENABLE_ALI_AGP)
-
-/* 
- * Option: ReqAGPRate
- *
- * Description:
- *
- * Normally, the driver will compare speed modes of the chipset & card,
- * picking the highest common rate. This key forces a maximum limit, to
- * limit the driver to lower speeds. The driver will not attempt a speed
- * beyond what the chipset and card claim they are capable of.
- *
- * Make sure you really know what you're doing before you enable this
- * override. By default, AGP drivers will enable the fastest AGP rate
- * your card and motherboard chipset are capable of. Then, in some cases,
- * our driver will force this rate down to work around bugs in both our
- * chipsets, and motherboard chipsets. Using this variable will override
- * our bug fixes. This may be desirable in some cases, but not most.
- *
- * This is completely unsupported!
- *
- * Possible Values:
- *
- *  This option expects a bitmask (15 = 8 | 4 | 2 | 1, etc.)
- *
- *  Note that on AGP 3.x chipsets, the only supported AGP rates are
- *  AGP 8x and AGP 4x (if set in ReqAGPRate, AGP 2x and 1x are
- *  ignored by the driver).
- *
- * This option is disabled by default, see below for information on how
- * to enable it.
- */
-
-#define __NV_REQ_AGP_RATE ReqAGPRate
-#define NV_REG_REQ_AGP_RATE NV_REG_STRING(__NV_REQ_AGP_RATE)
-
-/*  
- * Option: NvAGP
- *
- * Description: 
- *
- * This options controls which AGP GART driver is used when no explicit
- * request is made to change the default (X server).
- *
- * Possible Values:
- *
- *   0 = disable AGP support
- *   1 = use NVIDIA's builtin driver (if possible)
- *   2 = use the kernel's AGPGART driver (if possible)
- *   3 = use any available driver (try 1, then 2)
- *
- * Please note that NVIDIA's internal AGP GART driver will not be used
- * if AGPGART was either statically linked into your kernel or built as
- * a kernel module and loaded before the NVIDIA kernel module.
- */
-
-#define __NV_AGP NvAGP
-#define NV_REG_NV_AGP NV_REG_STRING(__NV_AGP)
-
-/* 
- * Option: EnableAGPSBA
- *
- * Description:
- *
- * For stability reasons, the driver will not Side Band Addressing even if
- * both the host chipset and the AGP card support it. You may override this
- * behaviour with the following registry key.
- *
- * This is completely unsupported!
- *
- * Possible Values:
- *
- *  0 = disable Side Band Addressing (default on x86, see below)
- *  1 = enable  Side Band Addressing (if supported)
- */
-
-/*
- * The default on x86 is to disable AGP side band addressing; if you want
- * to turn it on, change the registry key below.
- */
-
-#define __NV_ENABLE_AGPSBA EnableAGPSBA
-#define NV_REG_ENABLE_AGPSBA NV_REG_STRING(__NV_ENABLE_AGPSBA)
- 
-/*
- * Option: EnableAGPFW
- *
- * Description:
- *
- * Similar to Side Band Addressing, Fast Writes are disabled by default. If
- * you wish to enable them on systems that support them, you can do so with
- * this registry key. Please note that this may render your system unstable
- * with many AGP chipsets.
- *
- * This is completely unsupported!
- *
- * Possible Values:
- *
- *  0 = disable Fast Writes (default)
- *  1 = enable  Fast Writes (if supported)
- *
- * This option is disabled by default, see below for information on how
- * to enable it.
- */
-
-#define __NV_ENABLE_AGPFW EnableAGPFW
-#define NV_REG_ENABLE_AGPFW NV_REG_STRING(__NV_ENABLE_AGPFW)
-
-/* 
  * Option: Mobile
  *
  * Description:
@@ -469,19 +273,6 @@
 #define __NV_RM_MSG RmMsg
 #define NV_RM_MSG NV_REG_STRING(__NV_RM_MSG)
 
-/* 
- * Option: UseVBios
- *
- * Description:
- *
- * Use Video BIOS int10 code
- *
- * Default value: 1
- */
-
-#define __NV_USE_VBIOS UseVBios
-#define NV_REG_USE_VBIOS NV_REG_STRING(__NV_USE_VBIOS)
-
 /*
  * Option: RMEdgeIntrCheck
  *
@@ -541,14 +332,20 @@
  *
  * Possible Values:
  *
- *   0 = disable MSI interrupt (default)
- *   1 = enable MSI interrupt
+ *  0 = disable MSI interrupt (default on x86/x86-64)
+ *  1 = enable MSI interrupt (default on ARM)
  *
  */
 
 #define __NV_ENABLE_MSI EnableMSI
 #define NV_REG_ENABLE_MSI NV_REG_STRING(__NV_ENABLE_MSI)
 
+#if defined(NVCPU_ARM)
+#define __NV_ENABLE_MSI_DEFAULT 1
+#else
+#define __NV_ENABLE_MSI_DEFAULT 0
+#endif
+
 /*
  * Option: MapRegistersEarly
  *
@@ -572,28 +369,67 @@
  *
  * Description:
  *
- * When this option is enabled the NVIDIA driver will register with the ACPI
- * subsystems to receive ACPI events.
+ * When this option is enabled, the NVIDIA driver will register with the
+ * ACPI subsystem to receive notification of ACPI events.
  *
  * Possible values:
- * 1 - register for ACPI events (default)
- * 0 - do not register for ACPI events
+ *
+ *  1 - register for ACPI events (default)
+ *  0 - do not register for ACPI events
  */
 
 #define __NV_REGISTER_FOR_ACPI_EVENTS  RegisterForACPIEvents
 #define NV_REG_REGISTER_FOR_ACPI_EVENTS NV_REG_STRING(__NV_REGISTER_FOR_ACPI_EVENTS)
 
+/*
+ * Option: CheckPCIConfigSpace
+ *
+ * Description:
+ *
+ * When this option is enabled, the NVIDIA driver will perform checks upon
+ * entry to system calls, interrupts and various callbacks to determine
+ * if key registers in a given GPU's PCI configuration space, such as
+ * the PCI command register and BARs, were altered by third-party
+ * software.
+ *
+ * Possible values:
+ *
+ *  1 - perform PCI configuration space checks (default)
+ *  0 - do not perform PCI configuration space checks
+ */
+
+#define __NV_CHECK_PCI_CONFIG_SPACE  CheckPCIConfigSpace
+#define NV_REG_CHECK_PCI_CONFIG_SPACE NV_REG_STRING(__NV_CHECK_PCI_CONFIG_SPACE)
+
+/*
+ * Option: EnablePCIeGen3
+ *
+ * Description:
+ *
+ * Due to interoperability problems seen with Kepler PCIe Gen3 capable GPUs
+ * when configured on SandyBridge E desktop platforms, NVIDIA feels that
+ * delivering a reliable, high-quality experience is not currently possible in
+ * PCIe Gen3 mode on all PCIe Gen3 platforms. Therefore, Quadro, Tesla and
+ * NVS Kepler products operate in PCIe Gen2 mode by default. You may use this
+ * option to enable PCIe Gen3 support.
+ *
+ * This is completely unsupported!
+ *
+ * Possible Values:
+ *
+ *  0: disable PCIe Gen3 support (default)
+ *  1: enable PCIe Gen3 support
+ */
+
+#define __NV_ENABLE_PCIE_GEN3 EnablePCIeGen3
+#define NV_REG_ENABLE_PCIE_GEN3 NV_REG_STRING(__NV_ENABLE_PCIE_GEN3)
+
 #if defined(NV_DEFINE_REGISTRY_KEY_TABLE)
 
-/* 
+/*
  *---------registry key parameter declarations--------------
  */
 
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_VIA_4X, 0);
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_ALI_AGP, 0);
-NV_DEFINE_REG_ENTRY(__NV_REQ_AGP_RATE, 15);
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_AGPSBA, 0);
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_AGPFW, 0);
 NV_DEFINE_REG_ENTRY(__NV_MOBILE, ~0);
 NV_DEFINE_REG_ENTRY(__NV_RESMAN_DEBUG_LEVEL, ~0);
 NV_DEFINE_REG_ENTRY(__NV_RM_LOGON_RC, 1);
@@ -604,31 +440,19 @@ NV_DEFINE_REG_ENTRY(__NV_DEVICE_FILE_MODE, 0666);
 NV_DEFINE_REG_ENTRY(__NV_REMAP_LIMIT, 0);
 NV_DEFINE_REG_ENTRY(__NV_UPDATE_MEMORY_TYPES, ~0);
 NV_DEFINE_REG_ENTRY(__NV_INITIALIZE_SYSTEM_MEMORY_ALLOCATIONS, 1);
-NV_DEFINE_REG_ENTRY(__NV_USE_VBIOS, 1);
 NV_DEFINE_REG_ENTRY(__NV_RM_EDGE_INTR_CHECK, 1);
 NV_DEFINE_REG_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE, ~0);
-#if defined(NVCPU_ARM)
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 1);
-#else
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 0);
-#endif
 NV_DEFINE_REG_ENTRY(__NV_MAP_REGISTERS_EARLY, 0);
 NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
+NV_DEFINE_REG_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE, 1);
+NV_DEFINE_REG_ENTRY(__NV_ENABLE_PCIE_GEN3, 0);
+NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, __NV_ENABLE_MSI_DEFAULT);
 
 #if defined(NV_LINUX) || defined(NV_VMWARE)
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_RM_MSG, NULL);
 #endif
 
-#if (defined(NV_BSD) && defined(NV_SUPPORT_OS_AGP)) || defined(NV_LINUX)
-#define NV_DEFAULT_NV_AGP_VALUE 3
-#else
-#define NV_DEFAULT_NV_AGP_VALUE 1
-#endif
-
-NV_DEFINE_REG_ENTRY(__NV_AGP, NV_DEFAULT_NV_AGP_VALUE);
-
-
 /*
  *----------------registry database definition----------------------
  */
@@ -641,12 +465,6 @@ NV_DEFINE_REG_ENTRY(__NV_AGP, NV_DEFAULT_NV_AGP_VALUE);
  * kernel module.
  */
 nv_parm_t nv_parms[] = {
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_VIA_4X),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_ALI_AGP),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_AGP),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REQ_AGP_RATE),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_AGPSBA),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_AGPFW),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MOBILE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_RESMAN_DEBUG_LEVEL),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_RM_LOGON_RC),
@@ -657,12 +475,13 @@ nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REMAP_LIMIT),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_UPDATE_MEMORY_TYPES),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_INITIALIZE_SYSTEM_MEMORY_ALLOCATIONS),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_USE_VBIOS),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_RM_EDGE_INTR_CHECK),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_MSI),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MAP_REGISTERS_EARLY),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS),
+    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE),
+    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_PCIE_GEN3),
     {NULL, NULL, NULL}
 };
 
