@@ -126,11 +126,18 @@ static int nvidia_ctl_poll(
     mtx_lock(&filep->event_mtx);
     et = STAILQ_FIRST(&filep->event_queue);
 
-    if (et == NULL)
+    if (et == NULL) {
         selrecord(td, &filep->event_rsel);
+        et = STAILQ_FIRST(&filep->event_queue);
+    }
     else
         mask = (events & (POLLIN | POLLPRI | POLLRDNORM));
 
+    if ((et != NULL) && ((et->event.flags & NV_EVENT_FLAGS_DATA_VALID) == 0)) {
+        STAILQ_REMOVE(&filep->event_queue, et, nvidia_event, queue);
+        free(et, M_NVIDIA);
+    }
+
     mtx_unlock(&filep->event_mtx);
 
     return mask;
