@@ -244,47 +244,6 @@ void NV_API_CALL os_unmap_user_space(
 {
 }
 
-RM_STATUS NV_API_CALL os_set_mem_range(
-    NvU64 start,
-    NvU64 size,
-    NvU32 mode
-)
-{
-    int arg;
-    struct mem_range_desc mrd;
-
-    mrd.mr_base  = start;
-    mrd.mr_len   = size;
-    mrd.mr_flags = MDF_WRITECOMBINE;
-
-    strcpy(mrd.mr_owner, "NVIDIA");
-    arg = MEMRANGE_SET_UPDATE;
-
-    if (mem_range_attr_set(&mrd, &arg))
-        return RM_ERROR;
-
-    return RM_OK;
-}
-
-RM_STATUS NV_API_CALL os_unset_mem_range(
-    NvU64 start,
-    NvU64 size
-)
-{
-    int arg;
-    struct mem_range_desc mrd;
-
-    mrd.mr_base = start;
-    mrd.mr_len  = size;
-    arg = MEMRANGE_SET_REMOVE;
-
-    if (mem_range_attr_set(&mrd, &arg))
-        return RM_ERROR;
-
-    return RM_OK;
-}
-
-
 /*
  * The current debug level is used to determine if certain debug messages
  * are printed to the system console/log files or not. It defaults to the
@@ -457,7 +416,10 @@ RM_STATUS NV_API_CALL os_memcpy_from_user(
     NvU32 length
 )
 {
-    return copyin(src, dst, length)  ? RM_ERR_INVALID_POINTER : RM_OK;
+    if (src < (void *) VM_MAXUSER_ADDRESS)
+        return copyin(src, dst, length)  ? RM_ERR_INVALID_POINTER : RM_OK;
+
+    return os_mem_copy(dst, src, length) ? RM_ERR_INVALID_POINTER : RM_OK;
 }
 
 RM_STATUS NV_API_CALL os_memcpy_to_user(
@@ -466,7 +428,10 @@ RM_STATUS NV_API_CALL os_memcpy_to_user(
     NvU32 length
 )
 {
-    return copyout(src, dst, length) ? RM_ERR_INVALID_POINTER : RM_OK;
+    if (dst < (void *) VM_MAXUSER_ADDRESS)
+        return copyout(src, dst, length) ? RM_ERR_INVALID_POINTER : RM_OK;
+
+    return os_mem_copy(dst, src, length) ? RM_ERR_INVALID_POINTER : RM_OK;
 }
 
 void* NV_API_CALL os_mem_set(
@@ -551,6 +516,11 @@ RM_STATUS NV_API_CALL os_flush_user_cache(
     return RM_ERR_NOT_SUPPORTED;
 }
 
+RM_STATUS NV_API_CALL os_flush_cpu_cache_all(void)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
+
 static void sfence_action_func(void *arg)
 {
     __asm__ __volatile__("sfence": : :"memory");
@@ -572,116 +542,6 @@ RM_STATUS NV_API_CALL os_clear_smp_barrier(void)
     return RM_ERR_NOT_SUPPORTED;
 }
 
-void NV_API_CALL os_disable_preemption(void)
-{
-}
-
-void NV_API_CALL os_enable_preemption(void)
-{
-}
-
-struct os_mutex {
-    nv_stack_t *sp;
-    struct mtx mutex_mtx;
-    struct cv mutex_cv;
-    int refcnt;
-};
-
-RM_STATUS NV_API_CALL os_alloc_sema(void **semaphore)
-{
-    nv_stack_t *sp;
-    struct os_mutex *mtx;
-    RM_STATUS status;
-
-    NV_UMA_ZONE_ALLOC_STACK(sp);
-    if (sp == NULL)
-        return RM_ERR_NO_FREE_MEM;
-
-    status = os_alloc_mem((void **)&mtx, sizeof(struct os_mutex));
-    if (status != RM_OK) {
-        NV_UMA_ZONE_FREE_STACK(sp);
-        return status;
-    }
-
-    mtx_init(&mtx->mutex_mtx, "os.mutex_mtx", NULL, MTX_DEF | MTX_RECURSE);
-    cv_init(&mtx->mutex_cv, "os.mutex_cv");
-
-    mtx->sp = sp;
-    mtx->refcnt = 1;
-
-    *semaphore = (void *)mtx;
-
-    return RM_OK;
-}
-
-void NV_API_CALL os_free_sema(void *semaphore)
-{
-    struct os_mutex *mtx = semaphore;
-    nv_stack_t *sp;
-
-    sp = mtx->sp;
-    NV_UMA_ZONE_FREE_STACK(sp);
-
-    mtx_destroy(&mtx->mutex_mtx);
-    cv_destroy(&mtx->mutex_cv);
-
-    os_free_mem(semaphore);
-}
-
-RM_STATUS NV_API_CALL os_acquire_sema(void *semaphore)
-{
-    struct os_mutex *mtx = semaphore;
-
-    mtx_lock(&mtx->mutex_mtx);
-    if (mtx->refcnt > 0)
-        rm_disable_interrupts(mtx->sp);
-    mtx->refcnt--;
-    if (mtx->refcnt < 0)
-        cv_wait(&mtx->mutex_cv, &mtx->mutex_mtx);
-    mtx_unlock(&mtx->mutex_mtx);
-
-    return RM_OK;
-}
-
-RM_STATUS NV_API_CALL os_cond_acquire_sema(void *semaphore)
-{
-    struct os_mutex *mtx = semaphore;
-
-    mtx_lock(&mtx->mutex_mtx);
-    if (mtx->refcnt < 1) {
-        mtx_unlock(&mtx->mutex_mtx);
-        return RM_ERROR;
-    } else {
-        rm_disable_interrupts(mtx->sp);
-        mtx->refcnt--;
-        mtx_unlock(&mtx->mutex_mtx);
-    }
-
-    return RM_OK;
-}
-
-RM_STATUS NV_API_CALL os_release_sema(void *semaphore)
-{
-    struct os_mutex *mtx = semaphore;
-
-    mtx_lock(&mtx->mutex_mtx);
-    if (mtx->refcnt < 0)
-        cv_signal(&mtx->mutex_cv);
-    else
-        rm_enable_interrupts(mtx->sp);
-    mtx->refcnt++;
-    mtx_unlock(&mtx->mutex_mtx);
-
-    return RM_OK;
-}
-
-BOOL NV_API_CALL os_is_acquired_sema(void *semaphore)
-{
-    struct os_mutex *mtx = semaphore;
-    return (mtx->refcnt < 1);
-}
-
-
 RM_STATUS NV_API_CALL os_alloc_mutex(void **mutex)
 {
     RM_STATUS status;
