@@ -399,10 +399,6 @@ DRIVER_MODULE(nvidia, vgapci, nvidia_pci_driver, nvidia_devclass, nvidia_modeven
 MODULE_DEPEND(nvidia, mem, 1, 1, 1);
 MODULE_DEPEND(nvidia, io, 1, 1, 1);
 
-#ifdef NV_SUPPORT_OS_AGP
-MODULE_DEPEND(nvidia, agp, 1, 1, 1);
-#endif
-
 #ifdef NV_SUPPORT_LINUX_COMPAT /* (COMPAT_LINUX || COMPAT_LINUX32) */
 MODULE_DEPEND(nvidia, linux, 1, 1, 1);
 #endif
