@@ -25,8 +25,8 @@ nv_state_t nvidia_ctl_state;
 
 int nvidia_attach(device_t dev)
 {
-    int status;
-    NvU32 i;
+    RM_STATUS status;
+    NvU32 i, pmc_boot_0, pmc_boot_42;
     struct nvidia_softc *sc;
     nv_state_t *nv;
 
@@ -55,15 +55,21 @@ int nvidia_attach(device_t dev)
 
     pci_enable_io(dev, SYS_RES_MEMORY);
 
-    if ((status = rm_is_supported_device(sc->attach_sp, nv)) != RM_OK) {
-        nv_printf(NV_DBG_ERRORS,
-            "NVRM: The NVIDIA GPU %02x:%02x (PCI ID: %04x:%04x) installed\n"
-            "NVRM: in this system is not supported by the %s NVIDIA FreeBSD\n"
-            "NVRM: graphics driver release.  Please see 'Appendix A -\n"
-            "NVRM: Supported NVIDIA GPU Products' in this release's README,\n"
-            "NVRM: available on the FreeBSD graphics driver download page at\n"
-            "NVRM: www.nvidia.com.\n",
-            nv->bus, nv->slot, nv->vendor_id, nv->device_id, NV_VERSION_STRING);
+    if ((status = rm_is_supported_device(sc->attach_sp, nv, &pmc_boot_0,
+                                         &pmc_boot_42)) != RM_OK)
+    {
+        if ((status != RM_ERR_NOT_SUPPORTED) ||
+            !rm_is_legacy_arch(pmc_boot_0, pmc_boot_42))
+        {
+            nv_printf(NV_DBG_ERRORS,
+                "NVRM: The NVIDIA GPU %02x:%02x (PCI ID: %04x:%04x) installed\n"
+                "NVRM: in this system is not supported by the %s NVIDIA FreeBSD\n"
+                "NVRM: graphics driver release.  Please see 'Appendix A -\n"
+                "NVRM: Supported NVIDIA GPU Products' in this release's README,\n"
+                "NVRM: available on the FreeBSD graphics driver download page at\n"
+                "NVRM: www.nvidia.com.\n",
+                nv->bus, nv->slot, nv->vendor_id, nv->device_id, NV_VERSION_STRING);
+        }
         return ENXIO;
     }
 
@@ -83,7 +89,7 @@ int nvidia_attach(device_t dev)
             if (!sc->BAR_objects[i])
                 goto failed;
 
-            VM_OBJECT_WLOCK(sc->BAR_objects[i]);
+            VM_OBJECT_LOCK(sc->BAR_objects[i]);
             switch (i) {
                 case NV_GPU_BAR_INDEX_FB:
                     vm_object_set_memattr(sc->BAR_objects[i],
@@ -95,7 +101,7 @@ int nvidia_attach(device_t dev)
                             VM_MEMATTR_UNCACHEABLE);
                     break;
             }
-            VM_OBJECT_WUNLOCK(sc->BAR_objects[i]);
+            VM_OBJECT_UNLOCK(sc->BAR_objects[i]);
         }
     }
 
@@ -541,9 +547,9 @@ int nvidia_open_dev(
                 goto failed;
             }
 
-            VM_OBJECT_WLOCK(sc->UD_object);
+            VM_OBJECT_LOCK(sc->UD_object);
             vm_object_set_memattr(sc->UD_object, VM_MEMATTR_UNCACHEABLE);
-            VM_OBJECT_WUNLOCK(sc->UD_object);
+            VM_OBJECT_UNLOCK(sc->UD_object);
         }
 
         nv->flags |= NV_FLAG_OPEN;
@@ -700,255 +706,6 @@ int nvidia_modevent(
     return 0;
 }
 
-
-#ifdef NV_SUPPORT_OS_AGP
-NvS32 nv_os_agp_init(
-    nv_stack_t *sp,
-    nv_state_t *nv,
-    NvU64 *base,
-    NvU64 *limit
-)
-{
-    void *bitmap;
-    struct nvidia_softc *sc = nv->os_state;
-    struct agp_info ai;
-
-    NvU32 mode = 0;
-    NvU32 fw   = 0;
-    NvU32 sba  = 0;
-    NvU32 rate = (8 | 4 | 2 | 1);
-    NvU32 size = 0;
-
-    sc->agp_dev = agp_find_device();
-    if (!sc->agp_dev) {
-        printf("NVRM: agp_find_device failed, chipset unsupported?\n");
-        return ENODEV;
-    }
-
-    if (agp_acquire(sc->agp_dev) != 0)
-        return EBUSY;
-
-    agp_get_info(sc->agp_dev, &ai);
-    mode = ai.ai_mode;
-
-    if (os_set_mem_range(ai.ai_aperture_base, ai.ai_aperture_size,
-                NV_MEMORY_WRITECOMBINED) != RM_OK) {
-        /*
-         * Failure to set a write-combining range for the AGP aperture is
-         * not necessarily a fatal error condition; we don't know at this
-         * point, however, and abort to prevent performance and stability
-         * problems that may be hard to track down otherwise.
-         */
-        agp_release(sc->agp_dev);
-        return EIO;
-    }
-
-    rm_read_registry_dword(sp, NULL, "NVreg", "ReqAGPRate", &rate);
-    rm_read_registry_dword(sp, NULL, "NVreg", "EnableAGPFW", &fw);
-    rm_read_registry_dword(sp, NULL, "NVreg", "EnableAGPSBA", &sba);
-
-    if (AGP_MODE_GET_MODE_3(mode))
-        rate = (rate >> 2) & 3;
-    mode = AGP_MODE_SET_RATE(mode, AGP_MODE_GET_RATE(mode) & rate);
-    mode |= 1 /* avoid 0x mode request */;
-
-    if (AGP_MODE_GET_RATE(mode) & 2)
-        mode = AGP_MODE_SET_RATE(mode, AGP_MODE_GET_RATE(mode) & ~1);
-    if (AGP_MODE_GET_RATE(mode) & 4)
-        mode = AGP_MODE_SET_RATE(mode, AGP_MODE_GET_RATE(mode) & ~2);
-
-    mode = AGP_MODE_SET_FW(mode, fw);
-    mode = AGP_MODE_SET_SBA(mode, sba);
-
-    if (agp_enable(sc->agp_dev, mode) != 0) {
-        agp_release(sc->agp_dev);
-        os_unset_mem_range(ai.ai_aperture_base, ai.ai_aperture_size);
-        return EIO;
-    }
-
-    size = ai.ai_aperture_size / RM_PAGE_SIZE / 8;
-
-    if (os_alloc_mem((void **)&bitmap, size) != RM_OK) {
-        agp_release(sc->agp_dev);
-        os_unset_mem_range(ai.ai_aperture_base, ai.ai_aperture_size);
-        return EIO;
-    }
-
-    os_mem_set(bitmap, 0xff, size);
-
-    if (rm_set_agp_bitmap(sp, nv, bitmap) != RM_OK) {
-        agp_release(sc->agp_dev);
-        os_free_mem(bitmap);
-        os_unset_mem_range(ai.ai_aperture_base, ai.ai_aperture_size);
-        return EIO;
-    }
-
-    *base = ai.ai_aperture_base;
-    *limit = (ai.ai_aperture_size - 1);
-
-    return 0;
-}
-
-NvS32 nv_os_agp_teardown(
-    nv_stack_t *sp,
-    nv_state_t *nv
-)
-{
-    struct nvidia_softc *sc = nv->os_state;
-    void *bitmap;
-
-    if (agp_release(sc->agp_dev) != 0)
-        return EBUSY;
-
-    rm_clear_agp_bitmap(sp, nv, &bitmap);
-    os_free_mem(bitmap);
-
-    os_unset_mem_range(nv->agp.address, nv->agp.size);
-
-    return 0;
-}
-#endif /* NV_SUPPORT_OS_AGP */
-
-RM_STATUS NV_API_CALL nv_agp_init(
-    nv_state_t *nv,
-    NvU64 *base,
-    NvU64 *limit,
-    NvU32 config
-)
-{
-    struct nvidia_softc *sc = nv->os_state;
-    RM_STATUS status = RM_ERROR;
-    nv_stack_t *sp;
-
-    if (NV_AGP_ENABLED(nv))
-        return RM_ERR_STATE_IN_USE;
-
-    if (config == NVOS_AGP_CONFIG_DISABLE_AGP) {
-        /*
-         * Match the behavior on Linux, don't consider the attempt
-         * to initialize AGP as 'disabled' an error.
-         */
-        nv->agp_config = NVOS_AGP_CONFIG_DISABLE_AGP;
-        nv->agp_status = NV_AGP_STATUS_DISABLED;
-        return RM_OK;
-    }
-
-    NV_UMA_ZONE_ALLOC_STACK(sp);
-    if (sp == NULL)
-        return RM_ERR_NO_FREE_MEM;
-
-#ifdef NV_SUPPORT_OS_AGP
-    if ((config & NVOS_AGP_CONFIG_OSAGP) != 0) {
-        if (nv_os_agp_init(sp, nv, base, limit) == 0) {
-            /*
-             * If the operating system AGP GART driver successfully
-             * configured its backend, apply chipset overrides.
-             */
-            rm_update_agp_config(sp, nv);
-            NV_UMA_ZONE_FREE_STACK(sp);
-
-            nv->agp_config = NVOS_AGP_CONFIG_OSAGP;
-            nv->agp_status = NV_AGP_STATUS_ENABLED;
-        }
-    }
-#endif /* NV_SUPPORT_OS_AGP */
-
-    if (nv->agp_status != NV_AGP_STATUS_ENABLED) {
-        if ((config & NVOS_AGP_CONFIG_NVAGP) == 0) {
-            status = RM_ERR_NOT_SUPPORTED;
-            goto failed;
-        }
-
-        /*
-         * Make sure we don't try to use the internal GART driver when
-         * the OS AGPGART driver (agp.ko) is attached. While that may
-         * be perfectly fine on most systems, but is known to break on
-         * some.
-         * -------------------------------------------------------------
-         * DO NOT REDISTRIBUTE THE DRIVER WITH THIS SANITY CHECK REMOVED!
-         * -------------------------------------------------------------
-         */
-        if (devclass_get_softc(devclass_find("agp"), 0) != NULL) {
-            printf("NVRM: detected agp.ko, aborting NVIDIA AGP setup!\n");
-            goto failed;
-        }
-
-        status = rm_init_agp(sp, nv, base, limit);
-        if (status != RM_OK)
-            goto failed;
-        else {
-            NV_UMA_ZONE_FREE_STACK(sp);
-
-            nv->agp_config = NVOS_AGP_CONFIG_NVAGP;
-            nv->agp_status = NV_AGP_STATUS_ENABLED;
-        }
-    }
-
-    sc->AGP_sg_list = sglist_alloc(1, M_WAITOK);
-    if (!sc->AGP_sg_list) {
-        nv_agp_teardown(nv);
-        return RM_ERR_NO_FREE_MEM;
-    }
-
-    sglist_append_phys(sc->AGP_sg_list, *base, (*limit + 1));
-
-    sc->AGP_object = NV_VM_PAGER_ALLOCATE(OBJT_SG, sc->AGP_sg_list,
-            (*limit + 1), (VM_PROT_READ | VM_PROT_WRITE),
-            0, NULL);
-    if (!sc->AGP_object) {
-        NV_SGLIST_FREE(sc->AGP_sg_list);
-        nv_agp_teardown(nv);
-        return RM_ERR_NO_FREE_MEM;
-    }
-
-    VM_OBJECT_WLOCK(sc->AGP_object);
-    vm_object_set_memattr(sc->AGP_object, VM_MEMATTR_WRITE_COMBINING);
-    VM_OBJECT_WUNLOCK(sc->AGP_object);
-
-    return RM_OK;
-
-failed:
-    NV_UMA_ZONE_FREE_STACK(sp);
-
-    nv->agp_config = NVOS_AGP_CONFIG_DISABLE_AGP;
-    nv->agp_status = NV_AGP_STATUS_FAILED;
-
-    return status;
-}
-
-RM_STATUS NV_API_CALL nv_agp_teardown(nv_state_t *nv)
-{
-    struct nvidia_softc *sc = nv->os_state;
-    RM_STATUS status = RM_ERR_INVALID_STATE;
-    nv_stack_t *sp;
-
-    if (!NV_AGP_ENABLED(nv))
-        return status;
-
-    NV_UMA_ZONE_ALLOC_STACK(sp);
-    if (sp == NULL)
-        return RM_ERR_NO_FREE_MEM;
-
-    NV_VM_OBJECT_DEALLOCATE(sc->AGP_object);
-    NV_SGLIST_FREE(sc->AGP_sg_list);
-
-#ifdef NV_SUPPORT_OS_AGP
-    if (NV_OSAGP_ENABLED(nv)) {
-        status = (nv_os_agp_teardown(sp, nv) == 0)
-            ? RM_OK : RM_ERROR;
-    }
-#endif
-    if (NV_NVAGP_ENABLED(nv))
-        status = rm_teardown_agp(sp, nv);
-
-    NV_UMA_ZONE_FREE_STACK(sp);
-
-    nv->agp_config = NVOS_AGP_CONFIG_DISABLE_AGP;
-    nv->agp_status = NV_AGP_STATUS_DISABLED;
-
-    return status;
-}
-
 NvS32 NV_API_CALL nv_no_incoherent_mappings(void)
 {
     return 1;
@@ -970,7 +727,8 @@ void NV_API_CALL nv_post_event(
     nv_state_t *nv,
     nv_event_t *event,
     NvU32 hObject,
-    NvU32 index
+    NvU32 index,
+    NvBool data_valid
 )
 {
     struct nvidia_filep *filep = event->file;
@@ -983,6 +741,8 @@ void NV_API_CALL nv_post_event(
     et->event = *event;
     et->event.hObject = hObject;
     et->event.index = index;
+    if (data_valid)
+        et->event.flags |= NV_EVENT_FLAGS_DATA_VALID;
 
     mtx_lock(&filep->event_mtx);
     STAILQ_INSERT_TAIL(&filep->event_queue, et, queue);
@@ -1056,7 +816,7 @@ found:
 
     if (at->alloc_type_contiguous) {
         *private = NULL;
-        return (void *)(NvUPtr)(at->pte_array[0].virtual_address +
+        return (void *)(at->pte_array[0].virtual_address +
                     (i * PAGE_SIZE) + offset);
     }
 
@@ -1066,7 +826,7 @@ found:
     virtual_address = vm_map_min(kernel_map);
 
     status = vm_map_find(kernel_map, at->object, (i * PAGE_SIZE),
-            &virtual_address, size, 0, VMFS_ANY_SPACE,
+            &virtual_address, size, VMFS_ANY_SPACE,
             (VM_PROT_READ | VM_PROT_WRITE),
             (VM_PROT_READ | VM_PROT_WRITE), 0);
     if (status != KERN_SUCCESS) {
@@ -1181,7 +941,7 @@ NvS32 nv_alloc_contig_pages(
         return ENOMEM;
     }
 
-    address = kmem_alloc_contig(kmem_arena, size, flags, 0,
+    address = kmem_alloc_contig(kernel_map, size, flags, 0,
             sc->dma_mask, PAGE_SIZE, 0, attr);
     if (!address) {
         status = ENOMEM;
@@ -1211,9 +971,9 @@ NvS32 nv_alloc_contig_pages(
         goto failed;
     }
 
-    VM_OBJECT_WLOCK(at->object);
+    VM_OBJECT_LOCK(at->object);
     vm_object_set_memattr(at->object, attr);
-    VM_OBJECT_WUNLOCK(at->object);
+    VM_OBJECT_UNLOCK(at->object);
 
     *private = at;
     SLIST_INSERT_HEAD(&sc->alloc_list, at, list);
@@ -1230,7 +990,8 @@ failed:
         os_flush_cpu_cache();
 
     if (at->pte_array[0].virtual_address != NULL) {
-        kmem_free(kmem_arena, at->pte_array[0].virtual_address, at->size);
+        kmem_free(kernel_map,
+                at->pte_array[0].virtual_address, at->size);
         malloc_type_freed(M_NVIDIA, at->size);
     }
 
@@ -1256,7 +1017,8 @@ NvS32 nv_free_contig_pages(
     if (at->attr != VM_MEMATTR_WRITE_BACK)
         os_flush_cpu_cache();
 
-    kmem_free(kmem_arena, at->pte_array[0].virtual_address, at->size);
+    kmem_free(kernel_map, at->pte_array[0].virtual_address,
+            at->size);
     malloc_type_freed(M_NVIDIA, at->size);
 
     free(at->pte_array, M_NVIDIA);
@@ -1319,7 +1081,7 @@ NvS32 nv_alloc_system_pages(
     }
 
     for (i = 0; i < count; i++) {
-        address = kmem_alloc_contig(kmem_arena, PAGE_SIZE, flags, 0,
+        address = kmem_alloc_contig(kernel_map, PAGE_SIZE, flags, 0,
                 sc->dma_mask, PAGE_SIZE, 0, attr);
         if (!address) {
             status = ENOMEM;
@@ -1352,9 +1114,9 @@ NvS32 nv_alloc_system_pages(
         goto failed;
     }
 
-    VM_OBJECT_WLOCK(at->object);
+    VM_OBJECT_LOCK(at->object);
     vm_object_set_memattr(at->object, attr);
-    VM_OBJECT_WUNLOCK(at->object);
+    VM_OBJECT_UNLOCK(at->object);
 
     *private = at;
     SLIST_INSERT_HEAD(&sc->alloc_list, at, list);
@@ -1373,7 +1135,8 @@ failed:
     for (i = 0; i < count; i++) {
         if (at->pte_array[i].virtual_address == 0)
             break;
-        kmem_free(kmem_arena, at->pte_array[i].virtual_address, PAGE_SIZE);
+        kmem_free(kernel_map,
+                at->pte_array[i].virtual_address, PAGE_SIZE);
         malloc_type_freed(M_NVIDIA, PAGE_SIZE);
     }
 
@@ -1402,7 +1165,8 @@ NvS32 nv_free_system_pages(
         os_flush_cpu_cache();
 
     for (i = 0; i < count; i++) {
-        kmem_free(kmem_arena, at->pte_array[i].virtual_address, PAGE_SIZE);
+        kmem_free(kernel_map,
+                at->pte_array[i].virtual_address, PAGE_SIZE);
         malloc_type_freed(M_NVIDIA, PAGE_SIZE);
     }
 
@@ -1412,75 +1176,6 @@ NvS32 nv_free_system_pages(
     return 0;
 }
 
-#ifdef NV_SUPPORT_OS_AGP
-NvS32 nv_alloc_agp_pages(
-    nv_state_t *nv,
-    NvU32 count,
-    NvU32 offset,
-    void **private
-)
-{
-    void *handle;
-    struct nvidia_softc *sc = nv->os_state;
-
-    handle = agp_alloc_memory(sc->agp_dev, 0, count << PAGE_SHIFT);
-    if (!handle) {
-        /*
-         * This is very unlikely to happen, the system's memory resources
-         * would have to be nearly exhausted.
-         */
-        return ENOMEM;
-    }
-
-    os_flush_cpu_cache();
-
-    if (agp_bind_memory(sc->agp_dev, handle, offset) != 0) {
-        /*
-         * This shouldn't happen, we claimed the AGP backend and are thus
-         * using it exclusively; the resource manager manages AGP offsets
-         * internally, we wouldn't have been called had we run out of AGP
-         * aperture space.
-         */
-        os_dbg_breakpoint();
-
-        agp_free_memory(sc->agp_dev, handle);
-        return ENOMEM;
-    }
-
-    *private = handle;
-    return 0;
-}
-
-NvS32 nv_free_agp_pages(
-    nv_state_t *nv,
-    NvU32 count,
-    void *private,
-    NvU32 *offset
-)
-{
-    void *handle = private;
-    struct nvidia_softc *sc = nv->os_state;
-    struct agp_memory_info info;
-
-    agp_memory_info(sc->agp_dev, handle, &info);
-    *offset = info.ami_offset;
-
-    if (agp_unbind_memory(sc->agp_dev, handle) != 0) {
-        /*
-         * This is the only place where previously bound AGP memory would
-         * be freed. If we fail to unbind this memory now, something very
-         * wrong must have happened.
-         */
-        os_dbg_breakpoint();
-    }
-
-    os_flush_cpu_cache();
-    agp_free_memory(sc->agp_dev, handle);
-
-    return 0;
-}
-#endif /* NV_SUPPORT_OS_AGP */
-
 RM_STATUS NV_API_CALL nv_alias_pages(
     nv_state_t *nv,
     NvU32       count,
@@ -1508,7 +1203,6 @@ RM_STATUS NV_API_CALL nv_guest_pfn_list(
 RM_STATUS NV_API_CALL nv_alloc_pages(
     nv_state_t *nv,
     NvU32       count,
-    NvBool      alloc_type_agp,
     NvBool      alloc_type_contiguous,
     NvU32       cache_type,
     NvBool      alloc_type_zeroed,
@@ -1516,126 +1210,42 @@ RM_STATUS NV_API_CALL nv_alloc_pages(
     void      **private
 )
 {
-    NvU32 offset;
-    RM_STATUS status = RM_ERR_NO_FREE_MEM;
-    nv_stack_t *sp = NULL;
+    RM_STATUS status = RM_OK;
     NvBool zero = alloc_type_zeroed;
 
-    if (alloc_type_agp) {
-        if (!NV_AGP_ENABLED(nv))
-            return RM_ERR_NOT_SUPPORTED;
-
-        NV_UMA_ZONE_ALLOC_STACK(sp);
-        if (sp == NULL)
-            return RM_ERR_NO_FREE_MEM;
-
-#ifdef NV_SUPPORT_OS_AGP
-        if (NV_OSAGP_ENABLED(nv)) {
-            status = rm_alloc_agp_bitmap(sp, nv, count, &offset);
-            if (status != RM_OK)
-                goto failed;
-
-            if (nv_alloc_agp_pages(nv, count, (offset << PAGE_SHIFT),
-                    private) != 0) {
-                rm_free_agp_bitmap(sp, nv, count, offset);
-                goto failed;
-            }
-
-            NV_UMA_ZONE_FREE_STACK(sp);
-
-            pte_array[0] = (nv->agp.address + (offset << PAGE_SHIFT));
-            return RM_OK;
-        }
-#endif /* NV_SUPPORT_OS_AGP */
-
-        if (NV_NVAGP_ENABLED(nv)) {
-            status = rm_alloc_agp_pages(sp, nv, count, private, &offset);
-            if (status != RM_OK)
-                goto failed;
-
-            NV_UMA_ZONE_FREE_STACK(sp);
-
-            pte_array[0] = (nv->agp.address + (offset << PAGE_SHIFT));
-            return RM_OK;
+    if (!alloc_type_contiguous) {
+        if (nv_alloc_system_pages(nv, count, cache_type, zero,
+                    pte_array, private)) {
+            status = RM_ERR_NO_FREE_MEM;
         }
     } else {
-        if (!alloc_type_contiguous) {
-            if (nv_alloc_system_pages(nv, count, cache_type, zero,
-                        pte_array, private)) {
-                goto failed;
-            }
-        } else {
-            if (nv_alloc_contig_pages(nv, count, cache_type, zero,
-                        pte_array, private)) {
-                goto failed;
-            }
+        if (nv_alloc_contig_pages(nv, count, cache_type, zero,
+                    pte_array, private)) {
+            status = RM_ERR_NO_FREE_MEM;
         }
-        return RM_OK;
     }
 
-failed:
-    if (sp != NULL)
-        NV_UMA_ZONE_FREE_STACK(sp);
-
     return status;
 }
 
 RM_STATUS NV_API_CALL nv_free_pages(
     nv_state_t *nv,
     NvU32 count,
-    NvU32 alloc_type_agp,
-    NvU32 alloc_type_contiguous,
+    NvBool alloc_type_contiguous,
     NvU32 cache_type,
     void *private
 )
 {
-    RM_STATUS status = RM_ERROR;
-    nv_stack_t *sp = NULL;
+    RM_STATUS status = RM_OK;
 
-    if (alloc_type_agp) {
-        if (!NV_AGP_ENABLED(nv))
-            return RM_ERR_NOT_SUPPORTED;
-
-        NV_UMA_ZONE_ALLOC_STACK(sp);
-        if (sp == NULL)
-            return RM_ERR_NO_FREE_MEM;
-
-#ifdef NV_SUPPORT_OS_AGP
-        if (NV_OSAGP_ENABLED(nv)) {
-            NvU32 offset;
-
-            if (nv_free_agp_pages(nv, count, private, &offset) != 0)
-                goto failed;
-
-            rm_free_agp_bitmap(sp, nv, count, (offset >> PAGE_SHIFT));
-            NV_UMA_ZONE_FREE_STACK(sp);
-
-            return RM_OK;
-        }
-#endif /* NV_SUPPORT_OS_AGP */
-
-        if (NV_NVAGP_ENABLED(nv)) {
-            if (rm_free_agp_pages(sp, nv, private) != RM_OK)
-                goto failed;
-        }
-
-        NV_UMA_ZONE_FREE_STACK(sp);
-    } else {
-        if (!alloc_type_contiguous) {
-            if (nv_free_system_pages(nv, private))
-                goto failed;
-        } else  {
-            if (nv_free_contig_pages(nv, private))
-                goto failed;
-        }
+    if (!alloc_type_contiguous) {
+        if (nv_free_system_pages(nv, private))
+            status = RM_ERROR;
+    } else  {
+        if (nv_free_contig_pages(nv, private))
+            status = RM_ERROR;
     }
 
-    return RM_OK;
-
-failed:
-    if (sp != NULL)
-        NV_UMA_ZONE_FREE_STACK(sp);
-
     return status;
 }
 
@@ -1706,11 +1316,6 @@ int nvidia_mmap_dev_single(
         vm_object_reference(*object);
         *offset = (*offset - nv->regs->address);
         return 0;
-    } else if (IS_AGP_OFFSET(nv, *offset, size)) {
-        *object = sc->AGP_object;
-        vm_object_reference(*object);
-        *offset = (*offset - nv->agp.address);
-        return 0;
     }
 
     SLIST_FOREACH(at, &sc->alloc_list, list) {
@@ -1831,12 +1436,11 @@ void NV_API_CALL nv_verify_pci_config(
     BOOL check_the_bars
 )
 {
-    nv_stack_t *sp;
     struct nvidia_softc *sc = nv->os_state;
+    device_t dev = sc->dev;
+    nv_stack_t *sp = sc->pci_cfgchk_sp;
 
-    sp = sc->pci_cfgchk_sp;
-
-    NV_PCI_CHECK_CONFIG_SPACE(sp, nv, check_the_bars, FALSE, FALSE);
+    nvidia_pci_check_config_space(sp, dev, check_the_bars, FALSE, FALSE);
 }
 
 void NV_API_CALL nv_acpi_methods_init(NvU32 *handlesPresent)
