@@ -72,7 +72,7 @@ typedef struct
 NvU32       NV_API_CALL  os_get_page_size            (void);
 NvU64       NV_API_CALL  os_get_page_mask            (void);
 NvU64       NV_API_CALL  os_get_system_memory_size   (void);
-RM_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU64);
+RM_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU32);
 void        NV_API_CALL  os_free_mem                 (void *);
 RM_STATUS   NV_API_CALL  os_get_current_time         (NvU32 *, NvU32 *);
 RM_STATUS   NV_API_CALL  os_delay                    (NvU32);
@@ -102,11 +102,9 @@ void        NV_API_CALL  os_unmap_kernel_space       (void *, NvU64);
 void*       NV_API_CALL  os_map_user_space           (NvU64, NvU64, NvU32, NvU32, void **);
 void        NV_API_CALL  os_unmap_user_space         (void *, NvU64, void *);
 RM_STATUS   NV_API_CALL  os_flush_cpu_cache          (void);
+RM_STATUS   NV_API_CALL  os_flush_cpu_cache_all      (void);
 RM_STATUS   NV_API_CALL  os_flush_user_cache         (NvU64, NvU64, NvU64, NvU64, NvU32);
 void        NV_API_CALL  os_flush_cpu_write_combine_buffer(void);
-RM_STATUS   NV_API_CALL  os_set_mem_range            (NvU64, NvU64, NvU32, NvS32 *);
-RM_STATUS   NV_API_CALL  os_unset_mem_range          (NvU64, NvU64, NvS32);
-BOOL        NV_API_CALL  os_pci_device_present       (NvU16, NvU16);
 NvU8        NV_API_CALL  os_io_read_byte             (NvU32);
 NvU16       NV_API_CALL  os_io_read_word             (NvU32);
 NvU32       NV_API_CALL  os_io_read_dword            (NvU32);
@@ -122,17 +120,9 @@ RM_STATUS   NV_API_CALL  os_alloc_smp_barrier        (void);
 RM_STATUS   NV_API_CALL  os_free_smp_barrier         (void);
 RM_STATUS   NV_API_CALL  os_raise_smp_barrier        (void);
 RM_STATUS   NV_API_CALL  os_clear_smp_barrier        (void);
-void        NV_API_CALL  os_disable_preemption       (void);
-void        NV_API_CALL  os_enable_preemption        (void);
 RM_STATUS   NV_API_CALL  os_disable_console_access   (void);
 RM_STATUS   NV_API_CALL  os_enable_console_access    (void);
 RM_STATUS   NV_API_CALL  os_registry_init            (void);
-RM_STATUS   NV_API_CALL  os_alloc_sema               (void **);
-void        NV_API_CALL  os_free_sema                (void *);
-RM_STATUS   NV_API_CALL  os_acquire_sema             (void *);
-RM_STATUS   NV_API_CALL  os_cond_acquire_sema        (void *);
-RM_STATUS   NV_API_CALL  os_release_sema             (void *);
-BOOL        NV_API_CALL  os_is_acquired_sema         (void *);
 RM_STATUS   NV_API_CALL  os_schedule                 (void);
 RM_STATUS   NV_API_CALL  os_alloc_spinlock           (void **);
 void        NV_API_CALL  os_free_spinlock            (void *);
@@ -167,12 +157,6 @@ BOOL        NV_API_CALL  os_is_efi_enabled           (void);
  * ---------------------------------------------------------------------------
  */
 
-/* enable debugging if any OS debugging flag is set */
-#undef DEBUGGING
-#if defined(DEBUG) || defined(DBG)
-#define DEBUGGING
-#endif
-
 #if !defined(DBG_LEVEL_INFO)
 /*
  * Debug Level values
